@@ -1,12 +1,6 @@
 #![doc=include_str!("../README.md")]
 
 
-// Enable stdsimd for pmull on aarch64
-#![cfg_attr(
-    all(not(feature="no-xmul"), feature="nightly", target_arch="aarch64"),
-    feature(stdsimd)
-)]
-
 // We don't really need std
 #![no_std]
 
@@ -47,6 +41,8 @@ pub mod rs;
 
 
 /// Re-exports for proc_macros
+///
+/// Don't use these!
 #[path="."]
 pub mod internal {
     pub mod xmul;
@@ -55,7 +51,7 @@ pub mod internal {
     pub use rand;
 }
 
-/// A flag indicating if hardware carry-less multiplication instructions
-/// are available
+/// A flag indicating if hardware carry-less multiplication
+/// instructions are available
 pub use internal::xmul::HAS_XMUL;
 
